==> jc-1.4.0.tar.gz: soot/jimple/spark/solver/EBBCollapser.h <==
// public class soot.jimple.spark.solver.EBBCollapser

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2e97a5abe30cfb40 soot_jimple_spark_solver_EBBCollapser

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_spark_solver_EBBCollapser_H_
#define _JC_soot_jimple_spark_solver_EBBCollapser_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_jimple_spark_pag_PAG$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_solver_EBBCollapser$sub_refs	_jc_soot_jimple_spark_solver_EBBCollapser$sub_refs;
typedef struct _jc_soot_jimple_spark_solver_EBBCollapser$sub_nonrefs	_jc_soot_jimple_spark_solver_EBBCollapser$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_solver_EBBCollapser$refs	_jc_soot_jimple_spark_solver_EBBCollapser$refs;
typedef struct _jc_soot_jimple_spark_solver_EBBCollapser$nonrefs	_jc_soot_jimple_spark_solver_EBBCollapser$nonrefs;
typedef struct _jc_soot_jimple_spark_solver_EBBCollapser$object	_jc_soot_jimple_spark_solver_EBBCollapser$object;

typedef const struct _jc_soot_jimple_spark_solver_EBBCollapser$vmethods	_jc_soot_jimple_spark_solver_EBBCollapser$vmethods;
typedef const struct _jc_soot_jimple_spark_solver_EBBCollapser$vtable	_jc_soot_jimple_spark_solver_EBBCollapser$vtable;
typedef const struct _jc_soot_jimple_spark_solver_EBBCollapser$vtype	_jc_soot_jimple_spark_solver_EBBCollapser$vtype;

// Constructors
extern void _jc_soot_jimple_spark_solver_EBBCollapser$method$_init$d432acd4fd080ea1(_jc_env *, struct _jc_soot_jimple_spark_solver_EBBCollapser$object *, struct _jc_soot_jimple_spark_pag_PAG$object *);

// Virtual methods
extern void _jc_soot_jimple_spark_solver_EBBCollapser$method$collapse$485220070cfa5581(_jc_env *, struct _jc_soot_jimple_spark_solver_EBBCollapser$object *);
extern void _jc_soot_jimple_spark_solver_EBBCollapser$method$collapseAlloc$551b06d9e1572ebf(_jc_env *, struct _jc_soot_jimple_spark_solver_EBBCollapser$object *);
extern void _jc_soot_jimple_spark_solver_EBBCollapser$method$collapseLoad$8e7ed31bd6d127c4(_jc_env *, struct _jc_soot_jimple_spark_solver_EBBCollapser$object *);
extern void _jc_soot_jimple_spark_solver_EBBCollapser$method$collapseSimple$2dbecaec7812e639(_jc_env *, struct _jc_soot_jimple_spark_solver_EBBCollapser$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_solver_EBBCollapser$method_info$collapse$485220070cfa5581;
extern _jc_method _jc_soot_jimple_spark_solver_EBBCollapser$method_info$collapseAlloc$551b06d9e1572ebf;
extern _jc_method _jc_soot_jimple_spark_solver_EBBCollapser$method_info$collapseLoad$8e7ed31bd6d127c4;
extern _jc_method _jc_soot_jimple_spark_solver_EBBCollapser$method_info$collapseSimple$2dbecaec7812e639;

// Virtual methods structure
struct _jc_soot_jimple_spark_solver_EBBCollapser$vmethods {
	void	(*collapse$485220070cfa5581)(_jc_env *, struct _jc_soot_jimple_spark_solver_EBBCollapser$object *);
	void	(*collapseAlloc$551b06d9e1572ebf)(_jc_env *, struct _jc_soot_jimple_spark_solver_EBBCollapser$object *);
	void	(*collapseLoad$8e7ed31bd6d127c4)(_jc_env *, struct _jc_soot_jimple_spark_solver_EBBCollapser$object *);
	void	(*collapseSimple$2dbecaec7812e639)(_jc_env *, struct _jc_soot_jimple_spark_solver_EBBCollapser$object *);
};

// Vtable
struct _jc_soot_jimple_spark_solver_EBBCollapser$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_solver_EBBCollapser$vmethods	soot_jimple_spark_solver_EBBCollapser;
};

// Vtype
struct _jc_soot_jimple_spark_solver_EBBCollapser$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_solver_EBBCollapser$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_solver_EBBCollapser$sub_refs {
	struct _jc_soot_jimple_spark_pag_PAG$object	*pag;
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_solver_EBBCollapser$refs {
    _jc_soot_jimple_spark_solver_EBBCollapser$sub_refs	soot_jimple_spark_solver_EBBCollapser;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_solver_EBBCollapser$sub_nonrefs {
	jint	numCollapsed;
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_solver_EBBCollapser$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_solver_EBBCollapser$sub_nonrefs	soot_jimple_spark_solver_EBBCollapser;
};

// Object instance structure
struct _jc_soot_jimple_spark_solver_EBBCollapser$object {
	_jc_soot_jimple_spark_solver_EBBCollapser$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_solver_EBBCollapser$vtype	*vtype;
	_jc_soot_jimple_spark_solver_EBBCollapser$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_solver_EBBCollapser$vtype _jc_soot_jimple_spark_solver_EBBCollapser$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_solver_EBBCollapser, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_solver_EBBCollapser$class_object;

#endif	/* _JC_soot_jimple_spark_solver_EBBCollapser_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/spark/solver/EBBCollapser.h <==
// public class soot.jimple.spark.solver.EBBCollapser

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2e97a5abe30cfb40 soot_jimple_spark_solver_EBBCollapser

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_spark_solver_EBBCollapser_H_
#define _JC_soot_jimple_spark_solver_EBBCollapser_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_jimple_spark_pag_PAG$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_solver_EBBCollapser$sub_refs	_jc_soot_jimple_spark_solver_EBBCollapser$sub_refs;
typedef struct _jc_soot_jimple_spark_solver_EBBCollapser$sub_nonrefs	_jc_soot_jimple_spark_solver_EBBCollapser$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_solver_EBBCollapser$refs	_jc_soot_jimple_spark_solver_EBBCollapser$refs;
typedef struct _jc_soot_jimple_spark_solver_EBBCollapser$nonrefs	_jc_soot_jimple_spark_solver_EBBCollapser$nonrefs;
typedef struct _jc_soot_jimple_spark_solver_EBBCollapser$object	_jc_soot_jimple_spark_solver_EBBCollapser$object;

typedef const struct _jc_soot_jimple_spark_solver_EBBCollapser$vmethods	_jc_soot_jimple_spark_solver_EBBCollapser$vmethods;
typedef const struct _jc_soot_jimple_spark_solver_EBBCollapser$vtable	_jc_soot_jimple_spark_solver_EBBCollapser$vtable;
typedef const struct _jc_soot_jimple_spark_solver_EBBCollapser$vtype	_jc_soot_jimple_spark_solver_EBBCollapser$vtype;

// Constructors
extern void _jc_soot_jimple_spark_solver_EBBCollapser$method$_init$d432acd4fd080ea1(_jc_env *, struct _jc_soot_jimple_spark_solver_EBBCollapser$object *, struct _jc_soot_jimple_spark_pag_PAG$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_spark_solver_EBBCollapser$method$collapse$485220070cfa5581(_jc_env *, struct _jc_soot_jimple_spark_solver_EBBCollapser$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_spark_solver_EBBCollapser$method$collapseAlloc$551b06d9e1572ebf(_jc_env *, struct _jc_soot_jimple_spark_solver_EBBCollapser$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_spark_solver_EBBCollapser$method$collapseLoad$8e7ed31bd6d127c4(_jc_env *, struct _jc_soot_jimple_spark_solver_EBBCollapser$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_spark_solver_EBBCollapser$method$collapseSimple$2dbecaec7812e639(_jc_env *, struct _jc_soot_jimple_spark_solver_EBBCollapser$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_solver_EBBCollapser$method_info$collapse$485220070cfa5581;
extern _jc_method _jc_soot_jimple_spark_solver_EBBCollapser$method_info$collapseAlloc$551b06d9e1572ebf;
extern _jc_method _jc_soot_jimple_spark_solver_EBBCollapser$method_info$collapseLoad$8e7ed31bd6d127c4;
extern _jc_method _jc_soot_jimple_spark_solver_EBBCollapser$method_info$collapseSimple$2dbecaec7812e639;

// Virtual methods structure
struct _jc_soot_jimple_spark_solver_EBBCollapser$vmethods {
	void	(*collapse$485220070cfa5581)(_jc_env *, struct _jc_soot_jimple_spark_solver_EBBCollapser$object *) _JC_JCNI_ATTR;
	void	(*collapseAlloc$551b06d9e1572ebf)(_jc_env *, struct _jc_soot_jimple_spark_solver_EBBCollapser$object *) _JC_JCNI_ATTR;
	void	(*collapseLoad$8e7ed31bd6d127c4)(_jc_env *, struct _jc_soot_jimple_spark_solver_EBBCollapser$object *) _JC_JCNI_ATTR;
	void	(*collapseSimple$2dbecaec7812e639)(_jc_env *, struct _jc_soot_jimple_spark_solver_EBBCollapser$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_spark_solver_EBBCollapser$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_solver_EBBCollapser$vmethods	soot_jimple_spark_solver_EBBCollapser;
};

// Vtype
struct _jc_soot_jimple_spark_solver_EBBCollapser$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_solver_EBBCollapser$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_solver_EBBCollapser$sub_refs {
	struct _jc_soot_jimple_spark_pag_PAG$object	*pag;
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_solver_EBBCollapser$refs {
    _jc_soot_jimple_spark_solver_EBBCollapser$sub_refs	soot_jimple_spark_solver_EBBCollapser;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_solver_EBBCollapser$sub_nonrefs {
	jint	numCollapsed;
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_solver_EBBCollapser$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_solver_EBBCollapser$sub_nonrefs	soot_jimple_spark_solver_EBBCollapser;
};

// Object instance structure
struct _jc_soot_jimple_spark_solver_EBBCollapser$object {
	_jc_soot_jimple_spark_solver_EBBCollapser$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_solver_EBBCollapser$vtype	*vtype;
	_jc_soot_jimple_spark_solver_EBBCollapser$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_solver_EBBCollapser$vtype _jc_soot_jimple_spark_solver_EBBCollapser$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_solver_EBBCollapser, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_solver_EBBCollapser$class_object;

#endif	/* _JC_soot_jimple_spark_solver_EBBCollapser_H_ */
